/*
 * SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
 * SPDX-FileCopyrightText: 2015 Jakub Steiner <jimmac@gmail.com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */


.window-list-workspace-indicator .workspace {
  background-color: #ccc;
}

.window-list-workspace-indicator .workspace.active {
  border-color: #888;
}

.window-list-workspace-indicator-window-preview {
  background-color: #ededed;
  border: 1px solid #ccc;
}

.window-list-workspace-indicator-window-preview.active {
  background-color: #f6f5f4;
}
